TODO: replace this with manifests

NOTE: generalized RDF support is OPTIONAL.

## Positive cases

- `pos_001` - single frame, a set of quads that features all possible terms in any position. 
- `pos_002` - single frame, a set of quads that features all possible terms in any position and repeated across frame.
- `pos_003` - multiple frames (3), a set of quads with terms repeated across multiple frames. 
- `pos_004` - multiple frames (3), a set of quads with terms repeated across multiple frames, prefix table enabled.
- `pos_005` - multiple frames (3), a set of quads with terms repeated across multiple frames, prefix table enabled, focusing on reusing all three lookup tables.